@@ -94,9 +94,30 @@ Returns info about the channel of the current authenticated user.
 
 sub my_channel {
     my ($self) = @_;
+    $self->get_access_token() // return;
     return $self->_get_results($self->_make_channels_url(part => 'snippet', mine => 'true'));
 }
 
+=head2 my_channel_id()
+
+Returns the channel ID of the current authenticated user.
+
+=cut
+
+sub my_channel_id {
+    my ($self) = @_;
+
+    state $cache = {};
+
+    if (exists $cache->{id}) {
+        return $cache->{id};
+    }
+
+    $cache->{id} = undef;
+    my $channel = $self->my_channel() // return;
+    $cache->{id} = $channel->{results}{items}[0]{id} // return;
+}
+
 =head2 channels_my_subscribers()
 
 Retrieve a list of channels that subscribed to the authenticated user's channel.
@@ -137,6 +158,11 @@ Return the channel title for a given channel ID.
 
 sub channel_title_from_id {
     my ($self, $channel_id) = @_;
+
+    if ($channel_id eq 'mine') {
+        $channel_id = $self->my_channel_id();
+    }
+
     my $info = $self->channels_info($channel_id // return) // return;
 
     (    ref($info) eq 'HASH'
